summaryrefslogtreecommitdiff
path: root/tests/functional-tests
diff options
context:
space:
mode:
authorCarlos Garnacho <carlosg@gnome.org>2020-06-18 20:09:19 +0200
committerCarlos Garnacho <carlosg@gnome.org>2020-06-19 00:13:41 +0200
commit9c49a1d86a4a127ab703462de2d9391f027df723 (patch)
tree125bb96063201c91a7224a57448afbbd68c5715b /tests/functional-tests
parent72b936f79df0fb2ece6bb1152aa0df0b381ef451 (diff)
downloadtracker-9c49a1d86a4a127ab703462de2d9391f027df723.tar.gz
ontologies: Move tracker: ontology in 11-rdf.ontology to NRL
NRL is about defining the data structure, all our additional properties somehow belong in that same domain. This also moves all tracker:* properties and classes out of the base ontology (except for the tracker namespace itself, sadly, as it's needed for functions). All users have been updated to the new namespace for these properties and classes. Fixes: https://gitlab.gnome.org/GNOME/tracker/-/issues/226
Diffstat (limited to 'tests/functional-tests')
-rw-r--r--tests/functional-tests/ontology-changes.py40
-rw-r--r--tests/functional-tests/sparql-bugs.py2
-rw-r--r--tests/functional-tests/test-ontologies/add-class/91-test.ontology7
-rw-r--r--tests/functional-tests/test-ontologies/add-domainIndex/91-test.ontology11
-rw-r--r--tests/functional-tests/test-ontologies/add-prop/91-test.ontology7
-rw-r--r--tests/functional-tests/test-ontologies/basic-future/91-test.ontology7
-rw-r--r--tests/functional-tests/test-ontologies/basic/91-test.ontology7
-rw-r--r--tests/functional-tests/test-ontologies/cardinality/91-test.ontology7
-rw-r--r--tests/functional-tests/test-ontologies/indexed/91-test.ontology11
-rw-r--r--tests/functional-tests/test-ontologies/notify/91-test.ontology9
-rw-r--r--tests/functional-tests/test-ontologies/property-promotion/91-test.ontology7
-rw-r--r--tests/functional-tests/test-ontologies/property-range-int-to-string/91-test.ontology7
-rw-r--r--tests/functional-tests/test-ontologies/property-range-string-to-date/91-test.ontology7
-rw-r--r--tests/functional-tests/test-ontologies/superclass-remove/91-test.ontology7
14 files changed, 62 insertions, 74 deletions
diff --git a/tests/functional-tests/sparql-bugs.py b/tests/functional-tests/sparql-bugs.py
index ff997d2f1..bdd128f8c 100644
--- a/tests/functional-tests/sparql-bugs.py
+++ b/tests/functional-tests/sparql-bugs.py
@@ -180,7 +180,7 @@ class TrackerStoreSparqlBugsTests (fixtures.TrackerSparqlDirectTest):
"""
NB222645 - Inserting a resource using an non-existing class, doesn't rollback completely
"""
- query = "SELECT tracker:modified (?u) ?u WHERE { ?u a nco:Contact }"
+ query = "SELECT nrl:modified (?u) ?u WHERE { ?u a nco:Contact }"
original_data = self.tracker.query(query)
wrong_insert = "INSERT { <test://nb222645-wrong-class-contact> a nco:IMContact. } "
diff --git a/tests/functional-tests/test-ontologies/add-class/91-test.ontology b/tests/functional-tests/test-ontologies/add-class/91-test.ontology
index a4f231340..582cce0d3 100644
--- a/tests/functional-tests/test-ontologies/add-class/91-test.ontology
+++ b/tests/functional-tests/test-ontologies/add-class/91-test.ontology
@@ -1,6 +1,5 @@
@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#> .
@prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .
-@prefix tracker: <http://tracker.api.gnome.org/ontology/v3/tracker#> .
@prefix test: <http://example.org/ns#> .
@prefix xsd: <http://www.w3.org/2001/XMLSchema#> .
@prefix nrl: <http://tracker.api.gnome.org/ontology/v3/nrl#> .
@@ -14,9 +13,9 @@
# / \
# B C
#
-test: a tracker:Namespace, tracker:Ontology ;
- tracker:lastModified "2010-03-24T11:00:04Z" ;
- tracker:prefix "test" .
+test: a nrl:Namespace, nrl:Ontology ;
+ nrl:lastModified "2010-03-24T11:00:04Z" ;
+ nrl:prefix "test" .
test:A a rdfs:Class .
diff --git a/tests/functional-tests/test-ontologies/add-domainIndex/91-test.ontology b/tests/functional-tests/test-ontologies/add-domainIndex/91-test.ontology
index 0d224f49a..b67d63098 100644
--- a/tests/functional-tests/test-ontologies/add-domainIndex/91-test.ontology
+++ b/tests/functional-tests/test-ontologies/add-domainIndex/91-test.ontology
@@ -1,6 +1,5 @@
@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#> .
@prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .
-@prefix tracker: <http://tracker.api.gnome.org/ontology/v3/tracker#> .
@prefix test: <http://example.org/ns#> .
@prefix xsd: <http://www.w3.org/2001/XMLSchema#> .
@prefix nrl: <http://tracker.api.gnome.org/ontology/v3/nrl#> .
@@ -14,9 +13,9 @@
# / \
# B C
#
-test: a tracker:Namespace, tracker:Ontology ;
- tracker:lastModified "2010-03-24T11:00:04Z" ;
- tracker:prefix "test" .
+test: a nrl:Namespace, nrl:Ontology ;
+ nrl:lastModified "2010-03-24T11:00:04Z" ;
+ nrl:prefix "test" .
test:A a rdfs:Class .
@@ -58,7 +57,7 @@ test:a_superprop_n a rdf:Property ;
# ****** TEST CHANGE *****
test:B a rdfs:Class ;
- tracker:domainIndex test:a_string ;
+ nrl:domainIndex test:a_string ;
rdfs:subClassOf test:A .
# ************************
@@ -75,7 +74,7 @@ test:b_property_n a rdf:Property ;
# ****** TEST CHANGE *****
test:C a rdfs:Class ;
- tracker:domainIndex test:a_n_cardinality ;
+ nrl:domainIndex test:a_n_cardinality ;
rdfs:subClassOf test:A .
# *************************
diff --git a/tests/functional-tests/test-ontologies/add-prop/91-test.ontology b/tests/functional-tests/test-ontologies/add-prop/91-test.ontology
index 72fde9361..07ee94571 100644
--- a/tests/functional-tests/test-ontologies/add-prop/91-test.ontology
+++ b/tests/functional-tests/test-ontologies/add-prop/91-test.ontology
@@ -1,6 +1,5 @@
@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#> .
@prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .
-@prefix tracker: <http://tracker.api.gnome.org/ontology/v3/tracker#> .
@prefix test: <http://example.org/ns#> .
@prefix xsd: <http://www.w3.org/2001/XMLSchema#> .
@prefix nrl: <http://tracker.api.gnome.org/ontology/v3/nrl#> .
@@ -14,9 +13,9 @@
# / \
# B C
#
-test: a tracker:Namespace, tracker:Ontology ;
- tracker:lastModified "2010-03-24T11:00:04Z" ;
- tracker:prefix "test" .
+test: a nrl:Namespace, nrl:Ontology ;
+ nrl:lastModified "2010-03-24T11:00:04Z" ;
+ nrl:prefix "test" .
test:A a rdfs:Class .
diff --git a/tests/functional-tests/test-ontologies/basic-future/91-test.ontology b/tests/functional-tests/test-ontologies/basic-future/91-test.ontology
index 6dda3b2a1..fb15a14b5 100644
--- a/tests/functional-tests/test-ontologies/basic-future/91-test.ontology
+++ b/tests/functional-tests/test-ontologies/basic-future/91-test.ontology
@@ -1,6 +1,5 @@
@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#> .
@prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .
-@prefix tracker: <http://tracker.api.gnome.org/ontology/v3/tracker#> .
@prefix test: <http://example.org/ns#> .
@prefix xsd: <http://www.w3.org/2001/XMLSchema#> .
@prefix nrl: <http://tracker.api.gnome.org/ontology/v3/nrl#> .
@@ -14,9 +13,9 @@
# / \
# B C
#
-test: a tracker:Namespace, tracker:Ontology ;
- tracker:lastModified "2011-03-24T11:00:04Z" ;
- tracker:prefix "test" .
+test: a nrl:Namespace, nrl:Ontology ;
+ nrl:lastModified "2011-03-24T11:00:04Z" ;
+ nrl:prefix "test" .
test:A a rdfs:Class .
diff --git a/tests/functional-tests/test-ontologies/basic/91-test.ontology b/tests/functional-tests/test-ontologies/basic/91-test.ontology
index cae343eab..e5143a3b1 100644
--- a/tests/functional-tests/test-ontologies/basic/91-test.ontology
+++ b/tests/functional-tests/test-ontologies/basic/91-test.ontology
@@ -1,6 +1,5 @@
@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#> .
@prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .
-@prefix tracker: <http://tracker.api.gnome.org/ontology/v3/tracker#> .
@prefix test: <http://example.org/ns#> .
@prefix xsd: <http://www.w3.org/2001/XMLSchema#> .
@prefix nrl: <http://tracker.api.gnome.org/ontology/v3/nrl#> .
@@ -14,9 +13,9 @@
# / \
# B C
#
-test: a tracker:Namespace, tracker:Ontology ;
- tracker:lastModified "2010-03-23T11:00:04Z" ;
- tracker:prefix "test" .
+test: a nrl:Namespace, nrl:Ontology ;
+ nrl:lastModified "2010-03-23T11:00:04Z" ;
+ nrl:prefix "test" .
test:A a rdfs:Class .
diff --git a/tests/functional-tests/test-ontologies/cardinality/91-test.ontology b/tests/functional-tests/test-ontologies/cardinality/91-test.ontology
index 08e8b8faf..b7e972e8e 100644
--- a/tests/functional-tests/test-ontologies/cardinality/91-test.ontology
+++ b/tests/functional-tests/test-ontologies/cardinality/91-test.ontology
@@ -1,6 +1,5 @@
@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#> .
@prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .
-@prefix tracker: <http://tracker.api.gnome.org/ontology/v3/tracker#> .
@prefix test: <http://example.org/ns#> .
@prefix xsd: <http://www.w3.org/2001/XMLSchema#> .
@prefix nrl: <http://tracker.api.gnome.org/ontology/v3/nrl#> .
@@ -14,9 +13,9 @@
# / \
# B C
#
-test: a tracker:Namespace, tracker:Ontology ;
- tracker:lastModified "2010-03-24T11:00:04Z" ;
- tracker:prefix "test" .
+test: a nrl:Namespace, nrl:Ontology ;
+ nrl:lastModified "2010-03-24T11:00:04Z" ;
+ nrl:prefix "test" .
test:A a rdfs:Class .
diff --git a/tests/functional-tests/test-ontologies/indexed/91-test.ontology b/tests/functional-tests/test-ontologies/indexed/91-test.ontology
index 8b1b1a65b..f3db50629 100644
--- a/tests/functional-tests/test-ontologies/indexed/91-test.ontology
+++ b/tests/functional-tests/test-ontologies/indexed/91-test.ontology
@@ -1,6 +1,5 @@
@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#> .
@prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .
-@prefix tracker: <http://tracker.api.gnome.org/ontology/v3/tracker#> .
@prefix test: <http://example.org/ns#> .
@prefix xsd: <http://www.w3.org/2001/XMLSchema#> .
@prefix nrl: <http://tracker.api.gnome.org/ontology/v3/nrl#> .
@@ -14,9 +13,9 @@
# / \
# B C
#
-test: a tracker:Namespace, tracker:Ontology ;
- tracker:lastModified "2010-03-24T11:00:04Z" ;
- tracker:prefix "test" .
+test: a nrl:Namespace, nrl:Ontology ;
+ nrl:lastModified "2010-03-24T11:00:04Z" ;
+ nrl:prefix "test" .
test:A a rdfs:Class .
@@ -94,7 +93,7 @@ test:c_subprop_n a rdf:Property ;
test:a_n_cardinality a rdf:Property ;
rdfs:comment "Property to test the cardinality changes. indexed is false in basic" ;
rdfs:domain test:A ;
- tracker:indexed true ;
+ nrl:indexed true ;
rdfs:range xsd:string .
# Max cardinality N because is not specified
@@ -102,7 +101,7 @@ test:a_string a rdf:Property ;
rdfs:comment "Property to test the conversions from string" ;
rdfs:domain test:A ;
rdfs:range xsd:string ;
- tracker:indexed true ;
+ nrl:indexed true ;
nrl:maxCardinality 1 .
# *******************************
diff --git a/tests/functional-tests/test-ontologies/notify/91-test.ontology b/tests/functional-tests/test-ontologies/notify/91-test.ontology
index d60e3902c..307b5a51f 100644
--- a/tests/functional-tests/test-ontologies/notify/91-test.ontology
+++ b/tests/functional-tests/test-ontologies/notify/91-test.ontology
@@ -1,6 +1,5 @@
@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#> .
@prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .
-@prefix tracker: <http://tracker.api.gnome.org/ontology/v3/tracker#> .
@prefix test: <http://example.org/ns#> .
@prefix xsd: <http://www.w3.org/2001/XMLSchema#> .
@prefix nrl: <http://tracker.api.gnome.org/ontology/v3/nrl#> .
@@ -14,15 +13,15 @@
# / \
# B C
#
-test: a tracker:Namespace, tracker:Ontology ;
- tracker:lastModified "2010-03-24T11:00:04Z" ;
- tracker:prefix "test" .
+test: a nrl:Namespace, nrl:Ontology ;
+ nrl:lastModified "2010-03-24T11:00:04Z" ;
+ nrl:prefix "test" .
# ***** TEST CHANGE ******
# test:A a rdfs:Class .
test:A a rdfs:Class ;
- tracker:notify true .
+ nrl:notify true .
# ***************************
test:a_string a rdf:Property ;
diff --git a/tests/functional-tests/test-ontologies/property-promotion/91-test.ontology b/tests/functional-tests/test-ontologies/property-promotion/91-test.ontology
index d3442e9e9..f0916736d 100644
--- a/tests/functional-tests/test-ontologies/property-promotion/91-test.ontology
+++ b/tests/functional-tests/test-ontologies/property-promotion/91-test.ontology
@@ -1,6 +1,5 @@
@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#> .
@prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .
-@prefix tracker: <http://tracker.api.gnome.org/ontology/v3/tracker#> .
@prefix test: <http://example.org/ns#> .
@prefix xsd: <http://www.w3.org/2001/XMLSchema#> .
@prefix nrl: <http://tracker.api.gnome.org/ontology/v3/nrl#> .
@@ -14,9 +13,9 @@
# / \
# B C
#
-test: a tracker:Namespace, tracker:Ontology ;
- tracker:lastModified "2010-03-24T11:00:04Z" ;
- tracker:prefix "test" .
+test: a nrl:Namespace, nrl:Ontology ;
+ nrl:lastModified "2010-03-24T11:00:04Z" ;
+ nrl:prefix "test" .
test:A a rdfs:Class .
diff --git a/tests/functional-tests/test-ontologies/property-range-int-to-string/91-test.ontology b/tests/functional-tests/test-ontologies/property-range-int-to-string/91-test.ontology
index 56fc79da2..e45ba6657 100644
--- a/tests/functional-tests/test-ontologies/property-range-int-to-string/91-test.ontology
+++ b/tests/functional-tests/test-ontologies/property-range-int-to-string/91-test.ontology
@@ -1,6 +1,5 @@
@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#> .
@prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .
-@prefix tracker: <http://tracker.api.gnome.org/ontology/v3/tracker#> .
@prefix test: <http://example.org/ns#> .
@prefix xsd: <http://www.w3.org/2001/XMLSchema#> .
@prefix nrl: <http://tracker.api.gnome.org/ontology/v3/nrl#> .
@@ -14,9 +13,9 @@
# / \
# B C
#
-test: a tracker:Namespace, tracker:Ontology ;
- tracker:lastModified "2010-03-24T11:00:04Z" ;
- tracker:prefix "test" .
+test: a nrl:Namespace, nrl:Ontology ;
+ nrl:lastModified "2010-03-24T11:00:04Z" ;
+ nrl:prefix "test" .
test:A a rdfs:Class .
diff --git a/tests/functional-tests/test-ontologies/property-range-string-to-date/91-test.ontology b/tests/functional-tests/test-ontologies/property-range-string-to-date/91-test.ontology
index faa57b6c3..6749f79d8 100644
--- a/tests/functional-tests/test-ontologies/property-range-string-to-date/91-test.ontology
+++ b/tests/functional-tests/test-ontologies/property-range-string-to-date/91-test.ontology
@@ -1,6 +1,5 @@
@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#> .
@prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .
-@prefix tracker: <http://tracker.api.gnome.org/ontology/v3/tracker#> .
@prefix test: <http://example.org/ns#> .
@prefix xsd: <http://www.w3.org/2001/XMLSchema#> .
@prefix nrl: <http://tracker.api.gnome.org/ontology/v3/nrl#> .
@@ -14,9 +13,9 @@
# / \
# B C
#
-test: a tracker:Namespace, tracker:Ontology ;
- tracker:lastModified "2010-03-24T11:00:04Z" ;
- tracker:prefix "test" .
+test: a nrl:Namespace, nrl:Ontology ;
+ nrl:lastModified "2010-03-24T11:00:04Z" ;
+ nrl:prefix "test" .
test:A a rdfs:Class .
diff --git a/tests/functional-tests/test-ontologies/superclass-remove/91-test.ontology b/tests/functional-tests/test-ontologies/superclass-remove/91-test.ontology
index 3796ad57c..c884b39a3 100644
--- a/tests/functional-tests/test-ontologies/superclass-remove/91-test.ontology
+++ b/tests/functional-tests/test-ontologies/superclass-remove/91-test.ontology
@@ -1,6 +1,5 @@
@prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#> .
@prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#> .
-@prefix tracker: <http://tracker.api.gnome.org/ontology/v3/tracker#> .
@prefix test: <http://example.org/ns#> .
@prefix xsd: <http://www.w3.org/2001/XMLSchema#> .
@prefix nrl: <http://tracker.api.gnome.org/ontology/v3/nrl#> .
@@ -14,9 +13,9 @@
# / \
# B C
#
-test: a tracker:Namespace, tracker:Ontology ;
- tracker:lastModified "2010-03-24T11:00:04Z" ;
- tracker:prefix "test" .
+test: a nrl:Namespace, nrl:Ontology ;
+ nrl:lastModified "2010-03-24T11:00:04Z" ;
+ nrl:prefix "test" .
test:A a rdfs:Class .
diff --git a/tests/functional-tests/ontology-changes.py b/tests/functional-tests/ontology-changes.py
index 8a4b5491f..22cf767ac 100644
--- a/tests/functional-tests/ontology-changes.py
+++ b/tests/functional-tests/ontology-changes.py
@@ -155,9 +155,9 @@ class OntologyChangeTestTemplate (ut.TestCase):
def get_ontology_date(ontology):
with open(ontology, 'r') as f:
for line in f:
- if "tracker:lastModified" in line:
+ if "nrl:lastModified" in line:
getmodtime = re.compile(
- 'tracker:lastModified\ \"' + ISO9601_REGEX + '\"')
+ 'nrl:lastModified\ \"' + ISO9601_REGEX + '\"')
modtime_match = getmodtime.search(line)
if (modtime_match):
@@ -172,7 +172,7 @@ class OntologyChangeTestTemplate (ut.TestCase):
second_date = get_ontology_date(
self.ontology_path(second).joinpath("91-test.ontology"))
if first_date >= second_date:
- self.fail("tracker:lastModified in '%s' is not more recent in the second ontology" % (
+ self.fail("nrl:lastModified in '%s' is not more recent in the second ontology" % (
"91-test.ontology"))
@@ -365,7 +365,7 @@ class PropertyMaxCardinalityNto1 (OntologyChangeTestTemplate):
class ClassNotifySet (OntologyChangeTestTemplate):
"""
Set tracker:notify to true in a class and check there is no data loss
"""
def test_property_notify_set(self):
@@ -382,7 +382,7 @@ class ClassNotifySet (OntologyChangeTestTemplate):
def validate_status(self):
result = self.tracker.query(
- "SELECT ?notify WHERE { test:A tracker:notify ?notify}")
+ "SELECT ?notify WHERE { test:A nrl:notify ?notify}")
self.assertEqual(str(result[0][0]), "true")
result = self.tracker.query("SELECT ?u WHERE { ?u a test:A. }")
@@ -391,7 +391,7 @@ class ClassNotifySet (OntologyChangeTestTemplate):
class ClassNotifyUnset (OntologyChangeTestTemplate):
"""
Set tracker:notify to true in a class and check there is no data loss
"""
def test_property_notify_set(self):
@@ -408,7 +408,7 @@ class ClassNotifyUnset (OntologyChangeTestTemplate):
def validate_status(self):
result = self.tracker.query(
- "SELECT ?notify WHERE { test:A tracker:notify ?notify}")
+ "SELECT ?notify WHERE { test:A nrl:notify ?notify}")
if (len(result) == 1):
# Usually is (none) but it was "true" before so now has value.
self.assertEqual(result[0][0], "false")
@@ -421,7 +421,7 @@ class ClassNotifyUnset (OntologyChangeTestTemplate):
class PropertyIndexedSet (OntologyChangeTestTemplate):
"""
Set tracker:indexed true to single and multiple valued properties.
Check that instances and content of the property are still in the DB
"""
@@ -446,7 +446,7 @@ class PropertyIndexedSet (OntologyChangeTestTemplate):
def validate_status(self):
# Check ontology and instance for the single valued property
result = self.tracker.query(
- "SELECT ?indexed WHERE { test:a_string tracker:indexed ?indexed}")
+ "SELECT ?indexed WHERE { test:a_string nrl:indexed ?indexed}")
self.assertEqual(str(result[0][0]), "true")
result = self.tracker.query("SELECT ?content WHERE { <%s> a test:A; test:a_string ?content. }"
@@ -455,7 +455,7 @@ class PropertyIndexedSet (OntologyChangeTestTemplate):
# Check ontology and instance for the multiple valued property
result = self.tracker.query(
- "SELECT ?indexed WHERE { test:a_n_cardinality tracker:indexed ?indexed}")
+ "SELECT ?indexed WHERE { test:a_n_cardinality nrl:indexed ?indexed}")
self.assertEqual(str(result[0][0]), "true")
result = self.tracker.query("SELECT ?content WHERE { <%s> a test:A; test:a_n_cardinality ?content. }"
@@ -465,7 +465,7 @@ class PropertyIndexedSet (OntologyChangeTestTemplate):
class PropertyIndexedUnset (OntologyChangeTestTemplate):
"""
tracker:indexed property from true to false in single and multiple valued properties.
Check that instances and content of the property are still in the DB.
"""
@@ -489,12 +489,12 @@ class PropertyIndexedUnset (OntologyChangeTestTemplate):
def validate_status(self):
#
# NOTE: tracker:indexed can be 'false' or None. In both cases is fine.
#
# Check ontology and instance for the single valued property
result = self.tracker.query(
- "SELECT ?indexed WHERE { test:a_string tracker:indexed ?indexed}")
+ "SELECT ?indexed WHERE { test:a_string nrl:indexed ?indexed}")
self.assertEqual(str(result[0][0]), "false")
result = self.tracker.query("SELECT ?content WHERE { <%s> a test:A; test:a_string ?content. }"
@@ -503,7 +503,7 @@ class PropertyIndexedUnset (OntologyChangeTestTemplate):
# Check ontology and instance for the multiple valued property
result = self.tracker.query(
- "SELECT ?indexed WHERE { test:a_n_cardinality tracker:indexed ?indexed}")
+ "SELECT ?indexed WHERE { test:a_n_cardinality nrl:indexed ?indexed}")
self.assertEqual(str(result[0][0]), "false")
result = self.tracker.query("SELECT ?content WHERE { <%s> a test:A; test:a_n_cardinality ?content. }"
@@ -666,7 +666,7 @@ class OntologyRemovePropertyTest (OntologyChangeTestTemplate):
class DomainIndexAddTest (OntologyChangeTestTemplate):
"""
Add tracker:domainIndex to a class and check there is no data loss.
"""
@ut.skip("Fails with: basic-future/91-test.ontology: Unsupported ontology change for test:b_property: can't change rdfs:domain (old=test:A, attempted new=test:B) ")
def test_domain_index_add(self):
@@ -692,11 +692,11 @@ class DomainIndexAddTest (OntologyChangeTestTemplate):
def validate_status(self):
# Check the ontology
has_domainIndex = self.tracker.ask(
- "ASK { test:B tracker:domainIndex test:a_string }")
+ "ASK { test:B nrl:domainIndex test:a_string }")
self.assertTrue(has_domainIndex)
has_domainIndex = self.tracker.ask(
- "ASK { test:C tracker:domainIndex test:a_n_cardinality }")
+ "ASK { test:C nrl:domainIndex test:a_n_cardinality }")
self.assertTrue(has_domainIndex)
# Check the data
@@ -711,7 +711,7 @@ class DomainIndexAddTest (OntologyChangeTestTemplate):
class DomainIndexRemoveTest (OntologyChangeTestTemplate):
"""
Remove tracker:domainIndex to a class and check there is no data loss.
"""
def test_domain_index_remove(self):
@@ -737,11 +737,11 @@ class DomainIndexRemoveTest (OntologyChangeTestTemplate):
def validate_status(self):
# Check the ontology
has_domainIndex = self.tracker.ask(
- "ASK { test:B tracker:domainIndex test:a_string }")
+ "ASK { test:B nrl:domainIndex test:a_string }")
self.assertFalse(has_domainIndex)
has_domainIndex = self.tracker.ask(
- "ASK { test:C tracker:domainIndex test:a_n_cardinality }")
+ "ASK { test:C nrl:domainIndex test:a_n_cardinality }")
self.assertFalse(has_domainIndex)
# Check the data
@@ -365,7 +365,7 @@ class PropertyMaxCardinalityNto1 (OntologyChangeTestTemplate):
class ClassNotifySet (OntologyChangeTestTemplate):
"""
- Set tracker:notify to true in a class and check there is no data loss
+ Set nrl:notify to true in a class and check there is no data loss
"""
def test_property_notify_set(self):
@@ -391,7 +391,7 @@ class ClassNotifySet (OntologyChangeTestTemplate):
class ClassNotifyUnset (OntologyChangeTestTemplate):
"""
- Set tracker:notify to true in a class and check there is no data loss
+ Set nrl:notify to true in a class and check there is no data loss
"""
def test_property_notify_set(self):
@@ -421,7 +421,7 @@ class ClassNotifyUnset (OntologyChangeTestTemplate):
class PropertyIndexedSet (OntologyChangeTestTemplate):
"""
- Set tracker:indexed true to single and multiple valued properties.
+ Set nrl:indexed true to single and multiple valued properties.
Check that instances and content of the property are still in the DB
"""
@@ -465,7 +465,7 @@ class PropertyIndexedSet (OntologyChangeTestTemplate):
class PropertyIndexedUnset (OntologyChangeTestTemplate):
"""
- tracker:indexed property from true to false in single and multiple valued properties.
+ nrl:indexed property from true to false in single and multiple valued properties.
Check that instances and content of the property are still in the DB.
"""
@@ -489,12 +489,12 @@ class PropertyIndexedUnset (OntologyChangeTestTemplate):
def validate_status(self):
#
- # NOTE: tracker:indexed can be 'false' or None. In both cases is fine.
+ # NOTE: nrl:indexed can be 'false' or None. In both cases is fine.
#
# Check ontology and instance for the single valued property
@@ -666,7 +666,7 @@ class OntologyRemovePropertyTest (OntologyChangeTestTemplate):
class DomainIndexAddTest (OntologyChangeTestTemplate):
"""
- Add tracker:domainIndex to a class and check there is no data loss.
+ Add nrl:domainIndex to a class and check there is no data loss.
"""
@@ -711,7 +711,7 @@ class DomainIndexAddTest (OntologyChangeTestTemplate):
class DomainIndexRemoveTest (OntologyChangeTestTemplate):
"""
- Remove tracker:domainIndex to a class and check there is no data loss.
+ Remove nrl:domainIndex to a class and check there is no data loss.
"""
def test_domain_index_remove(self):